@@ -5,6 +5,7 @@ from django.contrib.auth.signals import user_logged_in
 from django.db import models
 from django.dispatch import receiver
 from django.utils.timezone import now
+from django_jsonfield_backport.models import JSONField
 
 from lavender.utils import texture_path_handler
 
@@ -74,6 +75,7 @@ class Texture(models.Model):
     created = models.DateTimeField(default=now)
     kind = models.CharField(max_length=6)
     deleted = models.BooleanField(default=False)
+    metadata = JSONField(default={})
 
     height = models.PositiveIntegerField(null=True)
     width = models.PositiveIntegerField(null=True)
